@@ -4,11 +4,12 @@ from ctc import binary
 def get_command_spec():
     return {
         'f': keccack_command,
+        'help': 'compute keccak hash of data',
         'args': [
             {'name': 'data'},
-            {'name': '--text', 'kwargs': {'action': 'store_true'}},
-            {'name': '--hex', 'kwargs': {'action': 'store_true'}},
-            {'name': '--raw', 'kwargs': {'action': 'store_true'}},
+            {'name': '--text', 'action': 'store_true'},
+            {'name': '--hex', 'action': 'store_true'},
+            {'name': '--raw', 'action': 'store_true'},
         ],
     }
 
