@@ -4,11 +4,12 @@ from ctc import rpc
 def get_command_spec():
     return {
         'f': async_call_command,
+        'help': 'output result of a call',
         'args': [
             {'name': 'to_address'},
             {'name': 'function_name'},
-            {'name': 'args', 'kwargs': {'nargs': '*'}},
-            {'name': '--quiet', 'kwargs': {'action': 'store_true'}},
+            {'name': 'args', 'nargs': '*'},
+            {'name': '--quiet', 'action': 'store_true'},
         ],
     }
 
