@@ -7,11 +7,12 @@ from ctc import rpc
 def get_command_spec():
     return {
         'f': async_swaps_command,
+        'help': 'output information about pool mints',
         'args': [
             {'name': 'pool'},
-            {'name': '--blocks', 'kwargs': {'nargs': '+'}},
+            {'name': '--blocks', 'nargs': '+'},
             {'name': '--output'},
-            {'name': '--overwrite', 'kwargs': {'action': 'store_true'}},
+            {'name': '--overwrite', 'action': 'store_true'},
         ],
     }
 
